# Library description
This library have useful functions for robotics labs. The robot dynamics and kinematics is computed using Pinocchio library.

## Install library:
Move to library location
<pre><code>$ cd robotics_python_lib/
</code></pre>
Build library
<pre><code>$ python3 setup.py bdist_wheel
</code></pre>
Install library
<pre><code>$ pip3 install dist/labpythonlib-4.0.0-py3-none-any.whl
</code></pre>
